@@ -130,6 +130,17 @@ module Google
       class BillingAccount
         include Google::Apis::Core::Hashable
       
+        # Optional. The currency in which the billing account is billed and charged,
+        # represented as an ISO 4217 code such as `USD`. Billing account currency is
+        # determined at the time of billing account creation and cannot be updated
+        # subsequently, so this field should not be set on update requests. In addition,
+        # a subaccount always matches the currency of its parent billing account, so
+        # this field should not be set on subaccount creation requests. Clients can read
+        # this field to determine the currency of an existing billing account.
+        # Corresponds to the JSON property `currencyCode`
+        # @return [String]
+        attr_accessor :currency_code
+      
         # The display name given to the billing account, such as `My Billing Account`.
         # This name is displayed in the Google Cloud Console.
         # Corresponds to the JSON property `displayName`
@@ -153,23 +164,34 @@ module Google
       
         # Output only. True if the billing account is open, and will therefore be
         # charged for any usage on associated projects. False if the billing account is
-        # closed, and therefore projects associated with it will be unable to use paid
+        # closed, and therefore projects associated with it are unable to use paid
         # services.
         # Corresponds to the JSON property `open`
         # @return [Boolean]
         attr_accessor :open
         alias_method :open?, :open
       
+        # Output only. The billing account's parent resource identifier. Use the `
+        # MoveBillingAccount` method to update the account's parent resource if it is a
+        # organization. Format: - `organizations/`organization_id``, for example, `
+        # organizations/12345678` - `billingAccounts/`billing_account_id``, for example,
+        # `billingAccounts/012345-567890-ABCDEF`
+        # Corresponds to the JSON property `parent`
+        # @return [String]
+        attr_accessor :parent
+      
         def initialize(**args)
            update!(**args)
         end
       
         # Update properties of this object
         def update!(**args)
+          @currency_code = args[:currency_code] if args.key?(:currency_code)
           @display_name = args[:display_name] if args.key?(:display_name)
           @master_billing_account = args[:master_billing_account] if args.key?(:master_billing_account)
           @name = args[:name] if args.key?(:name)
           @open = args[:open] if args.key?(:open)
+          @parent = args[:parent] if args.key?(:parent)
         end
       end
       
@@ -211,7 +233,27 @@ module Google
         # kubernetes-engine/docs/how-to/kubernetes-service-accounts). For example, `my-
         # project.svc.id.goog[my-namespace/my-kubernetes-sa]`. * `group:`emailid``: An
         # email address that represents a Google group. For example, `admins@example.com`
-        # . * `deleted:user:`emailid`?uid=`uniqueid``: An email address (plus unique
+        # . * `domain:`domain``: The G Suite domain (primary) that represents all the
+        # users of that domain. For example, `google.com` or `example.com`. * `principal:
+        # //iam.googleapis.com/locations/global/workforcePools/`pool_id`/subject/`
+        # subject_attribute_value``: A single identity in a workforce identity pool. * `
+        # principalSet://iam.googleapis.com/locations/global/workforcePools/`pool_id`/
+        # group/`group_id``: All workforce identities in a group. * `principalSet://iam.
+        # googleapis.com/locations/global/workforcePools/`pool_id`/attribute.`
+        # attribute_name`/`attribute_value``: All workforce identities with a specific
+        # attribute value. * `principalSet://iam.googleapis.com/locations/global/
+        # workforcePools/`pool_id`/*`: All identities in a workforce identity pool. * `
+        # principal://iam.googleapis.com/projects/`project_number`/locations/global/
+        # workloadIdentityPools/`pool_id`/subject/`subject_attribute_value``: A single
+        # identity in a workload identity pool. * `principalSet://iam.googleapis.com/
+        # projects/`project_number`/locations/global/workloadIdentityPools/`pool_id`/
+        # group/`group_id``: A workload identity pool group. * `principalSet://iam.
+        # googleapis.com/projects/`project_number`/locations/global/
+        # workloadIdentityPools/`pool_id`/attribute.`attribute_name`/`attribute_value``:
+        # All identities in a workload identity pool with a certain attribute. * `
+        # principalSet://iam.googleapis.com/projects/`project_number`/locations/global/
+        # workloadIdentityPools/`pool_id`/*`: All identities in a workload identity pool.
+        # * `deleted:user:`emailid`?uid=`uniqueid``: An email address (plus unique
         # identifier) representing a user that has been recently deleted. For example, `
         # alice@example.com?uid=123456789012345678901`. If the user is recovered, this
         # value reverts to `user:`emailid`` and the recovered user retains the role in
@@ -225,14 +267,19 @@ module Google
         # been recently deleted. For example, `admins@example.com?uid=
         # 123456789012345678901`. If the group is recovered, this value reverts to `
         # group:`emailid`` and the recovered group retains the role in the binding. * `
-        # domain:`domain``: The G Suite domain (primary) that represents all the users
-        # of that domain. For example, `google.com` or `example.com`.
+        # deleted:principal://iam.googleapis.com/locations/global/workforcePools/`
+        # pool_id`/subject/`subject_attribute_value``: Deleted single identity in a
+        # workforce identity pool. For example, `deleted:principal://iam.googleapis.com/
+        # locations/global/workforcePools/my-pool-id/subject/my-subject-attribute-value`.
         # Corresponds to the JSON property `members`
         # @return [Array<String>]
         attr_accessor :members
       
         # Role that is assigned to the list of `members`, or principals. For example, `
-        # roles/viewer`, `roles/editor`, or `roles/owner`.
+        # roles/viewer`, `roles/editor`, or `roles/owner`. For an overview of the IAM
+        # roles and permissions, see the [IAM documentation](https://cloud.google.com/
+        # iam/docs/roles-overview). For a list of the available pre-defined roles, see [
+        # here](https://cloud.google.com/iam/docs/understanding-roles).
         # Corresponds to the JSON property `role`
         # @return [String]
         attr_accessor :role
@@ -514,6 +561,26 @@ module Google
         end
       end
       
+      # Request message for `MoveBillingAccount` RPC.
+      class MoveBillingAccountRequest
+        include Google::Apis::Core::Hashable
+      
+        # Required. The resource name of the Organization to move the billing account
+        # under. Must be of the form `organizations/`organization_id``.
+        # Corresponds to the JSON property `destinationParent`
+        # @return [String]
+        attr_accessor :destination_parent
+      
+        def initialize(**args)
+           update!(**args)
+        end
+      
+        # Update properties of this object
+        def update!(**args)
+          @destination_parent = args[:destination_parent] if args.key?(:destination_parent)
+        end
+      end
+      
       # An Identity and Access Management (IAM) policy, which specifies access
       # controls for Google Cloud resources. A `Policy` is a collection of `bindings`.
       # A `binding` binds one or more `members`, or principals, to a single `role`.
@@ -525,22 +592,22 @@ module Google
       # evaluates to `true`. A condition can add constraints based on attributes of
       # the request, the resource, or both. To learn which resources support
       # conditions in their IAM policies, see the [IAM documentation](https://cloud.
-      # google.com/iam/help/conditions/resource-policies). **JSON example:** ` "
+      # google.com/iam/help/conditions/resource-policies). **JSON example:** ``` ` "
       # bindings": [ ` "role": "roles/resourcemanager.organizationAdmin", "members": [
       # "user:mike@example.com", "group:admins@example.com", "domain:google.com", "
       # serviceAccount:my-project-id@appspot.gserviceaccount.com" ] `, ` "role": "
       # roles/resourcemanager.organizationViewer", "members": [ "user:eve@example.com"
       # ], "condition": ` "title": "expirable access", "description": "Does not grant
       # access after Sep 2020", "expression": "request.time < timestamp('2020-10-01T00:
-      # 00:00.000Z')", ` ` ], "etag": "BwWWja0YfJA=", "version": 3 ` **YAML example:**
-      # bindings: - members: - user:mike@example.com - group:admins@example.com -
-      # domain:google.com - serviceAccount:my-project-id@appspot.gserviceaccount.com
-      # role: roles/resourcemanager.organizationAdmin - members: - user:eve@example.
-      # com role: roles/resourcemanager.organizationViewer condition: title: expirable
-      # access description: Does not grant access after Sep 2020 expression: request.
-      # time < timestamp('2020-10-01T00:00:00.000Z') etag: BwWWja0YfJA= version: 3 For
-      # a description of IAM and its features, see the [IAM documentation](https://
-      # cloud.google.com/iam/docs/).
+      # 00:00.000Z')", ` ` ], "etag": "BwWWja0YfJA=", "version": 3 ` ``` **YAML
+      # example:** ``` bindings: - members: - user:mike@example.com - group:admins@
+      # example.com - domain:google.com - serviceAccount:my-project-id@appspot.
+      # gserviceaccount.com role: roles/resourcemanager.organizationAdmin - members: -
+      # user:eve@example.com role: roles/resourcemanager.organizationViewer condition:
+      # title: expirable access description: Does not grant access after Sep 2020
+      # expression: request.time < timestamp('2020-10-01T00:00:00.000Z') etag:
+      # BwWWja0YfJA= version: 3 ``` For a description of IAM and its features, see the
+      # [IAM documentation](https://cloud.google.com/iam/docs/).
       class Policy
         include Google::Apis::Core::Hashable
       
@@ -748,26 +815,26 @@ module Google
         # @return [String]
         attr_accessor :billing_account_name
       
-        # True if the project is associated with an open billing account, to which usage
-        # on the project is charged. False if the project is associated with a closed
-        # billing account, or no billing account at all, and therefore cannot use paid
-        # services. This field is read-only.
+        # Output only. True if the project is associated with an open billing account,
+        # to which usage on the project is charged. False if the project is associated
+        # with a closed billing account, or no billing account at all, and therefore
+        # cannot use paid services.
         # Corresponds to the JSON property `billingEnabled`
         # @return [Boolean]
         attr_accessor :billing_enabled
         alias_method :billing_enabled?, :billing_enabled
       
-        # The resource name for the `ProjectBillingInfo`; has the form `projects/`
-        # project_id`/billingInfo`. For example, the resource name for the billing
-        # information for project `tokyo-rain-123` would be `projects/tokyo-rain-123/
-        # billingInfo`. This field is read-only.
+        # Output only. The resource name for the `ProjectBillingInfo`; has the form `
+        # projects/`project_id`/billingInfo`. For example, the resource name for the
+        # billing information for project `tokyo-rain-123` would be `projects/tokyo-rain-
+        # 123/billingInfo`.
         # Corresponds to the JSON property `name`
         # @return [String]
         attr_accessor :name
       
-        # The ID of the project that this `ProjectBillingInfo` represents, such as `
-        # tokyo-rain-123`. This is a convenience field so that you don't need to parse
-        # the `name` field to obtain a project ID. This field is read-only.
+        # Output only. The ID of the project that this `ProjectBillingInfo` represents,
+        # such as `tokyo-rain-123`. This is a convenience field so that you don't need
+        # to parse the `name` field to obtain a project ID.
         # Corresponds to the JSON property `projectId`
         # @return [String]
         attr_accessor :project_id
@@ -800,12 +867,12 @@ module Google
         # @return [String]
         attr_accessor :display_name
       
-        # The resource name for the service. Example: "services/DA34-426B-A397"
+        # The resource name for the service. Example: "services/6F81-5844-456A"
         # Corresponds to the JSON property `name`
         # @return [String]
         attr_accessor :name
       
-        # The identifier for the service. Example: "DA34-426B-A397"
+        # The identifier for the service. Example: "6F81-5844-456A"
         # Corresponds to the JSON property `serviceId`
         # @return [String]
         attr_accessor :service_id
@@ -838,22 +905,22 @@ module Google
         # evaluates to `true`. A condition can add constraints based on attributes of
         # the request, the resource, or both. To learn which resources support
         # conditions in their IAM policies, see the [IAM documentation](https://cloud.
-        # google.com/iam/help/conditions/resource-policies). **JSON example:** ` "
+        # google.com/iam/help/conditions/resource-policies). **JSON example:** ``` ` "
         # bindings": [ ` "role": "roles/resourcemanager.organizationAdmin", "members": [
         # "user:mike@example.com", "group:admins@example.com", "domain:google.com", "
         # serviceAccount:my-project-id@appspot.gserviceaccount.com" ] `, ` "role": "
         # roles/resourcemanager.organizationViewer", "members": [ "user:eve@example.com"
         # ], "condition": ` "title": "expirable access", "description": "Does not grant
         # access after Sep 2020", "expression": "request.time < timestamp('2020-10-01T00:
-        # 00:00.000Z')", ` ` ], "etag": "BwWWja0YfJA=", "version": 3 ` **YAML example:**
-        # bindings: - members: - user:mike@example.com - group:admins@example.com -
-        # domain:google.com - serviceAccount:my-project-id@appspot.gserviceaccount.com
-        # role: roles/resourcemanager.organizationAdmin - members: - user:eve@example.
-        # com role: roles/resourcemanager.organizationViewer condition: title: expirable
-        # access description: Does not grant access after Sep 2020 expression: request.
-        # time < timestamp('2020-10-01T00:00:00.000Z') etag: BwWWja0YfJA= version: 3 For
-        # a description of IAM and its features, see the [IAM documentation](https://
-        # cloud.google.com/iam/docs/).
+        # 00:00.000Z')", ` ` ], "etag": "BwWWja0YfJA=", "version": 3 ` ``` **YAML
+        # example:** ``` bindings: - members: - user:mike@example.com - group:admins@
+        # example.com - domain:google.com - serviceAccount:my-project-id@appspot.
+        # gserviceaccount.com role: roles/resourcemanager.organizationAdmin - members: -
+        # user:eve@example.com role: roles/resourcemanager.organizationViewer condition:
+        # title: expirable access description: Does not grant access after Sep 2020
+        # expression: request.time < timestamp('2020-10-01T00:00:00.000Z') etag:
+        # BwWWja0YfJA= version: 3 ``` For a description of IAM and its features, see the
+        # [IAM documentation](https://cloud.google.com/iam/docs/).
         # Corresponds to the JSON property `policy`
         # @return [Google::Apis::CloudbillingV1::Policy]
         attr_accessor :policy
@@ -876,7 +943,7 @@ module Google
         end
       end
       
-      # Encapsulates a single SKU in Google Cloud Platform
+      # Encapsulates a single SKU in Google Cloud
       class Sku
         include Google::Apis::Core::Hashable
       
@@ -896,8 +963,8 @@ module Google
         # @return [Google::Apis::CloudbillingV1::GeoTaxonomy]
         attr_accessor :geo_taxonomy
       
-        # The resource name for the SKU. Example: "services/DA34-426B-A397/skus/AA95-
-        # CD31-42FE"
+        # The resource name for the SKU. Example: "services/6F81-5844-456A/skus/D041-
+        # B8A1-6E0B"
         # Corresponds to the JSON property `name`
         # @return [String]
         attr_accessor :name
@@ -919,7 +986,7 @@ module Google
         # @return [Array<String>]
         attr_accessor :service_regions
       
-        # The identifier for the SKU. Example: "AA95-CD31-42FE"
+        # The identifier for the SKU. Example: "D041-B8A1-6E0B"
         # Corresponds to the JSON property `skuId`
         # @return [String]
         attr_accessor :sku_id
